@@ -11,12 +11,15 @@ struct PGrnBuffers
 	grn_obj ctid;
 	grn_obj score;
 	grn_obj sourceIDs;
+	grn_obj tokenizer;
+	grn_obj normalizer;
 	grn_obj tokenFilters;
 	grn_obj jsonbValueKeys;
 	grn_obj walPosition;
 	grn_obj walValue;
 	grn_obj maxRecordSize;
 	grn_obj walAppliedPosition;
+	grn_obj isTargets;
 	struct
 	{
 		grn_obj escapedValue;
